@@ -2,7 +2,12 @@
 # Author: Steven Shiau <steven _at_ nchc org tw>
 # License: GPL
 
-. /opt/drbl/sbin/drbl-conf-functions
+#
+DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
+
+. $DRBL_SCRIPT_PATH/sbin/drbl-conf-functions
+. $DRBL_SCRIPT_PATH/conf/drbl-ocs.conf
+. $DRBL_SCRIPT_PATH/sbin/ocs-functions
 
 # functions
 USAGE() {
